@@ -249,8 +249,8 @@ class CardBase:
                         label = self.label_from_field(field=field, field_type=field_type)
         return value, label, field_type
 
-    def _add_many_to_many_field(self, label, query, query_filter, m2m_field,
-                                html_barge, default='N/A', html_override=None,
+    def _add_many_to_many_field(self, label, query, query_filter=None, m2m_field=None,
+                                html_barge=None, default='N/A', html_override=None,
                                 entry_css_class=None, css_class=None, menu=None, default_if=None, **kwargs):
         if html_barge is None:
             html_barge = '<span class="small badge badge-pill badge-primary"> %1% </span> '
@@ -312,9 +312,6 @@ class CardBase:
         elif hasattr(value, 'through'):
             return self._add_many_to_many_field(label=label,
                                                 query=value,
-                                                query_filter=kwargs.get('query_filter'),
-                                                html_barge=kwargs.get('html_barge'),
-                                                m2m_field=kwargs.get('m2m_field'),
                                                 default=default,
                                                 html_override=html_override,
                                                 entry_css_class=entry_css_class,
